// if user didn't opt consent, preferences is an empty string
window.cookieProPreferences = localStorage.getItem("cookieProPrefences")
  ? JSON.parse(localStorage.getItem("cookieProPrefences"))
  : ""

// Polyfill for IE
if (!NodeList.prototype.forEach)
  NodeList.prototype.forEach = Array.prototype.forEach

var scriptsArray = [],
  preferences = window.cookieProPreferences,
  document_height = document.documentElement.clientHeight,
  scripts = document.getElementsByTagName("script"),
  consent = document.getElementById("my-cookie__consent"),
  popup = document.getElementById("my-cookie__popup"),
  delay = consent.getAttribute("data-delay"),
  delay_px = parseInt(consent.getAttribute("data-delay-px")),
  delay_vh = parseInt(consent.getAttribute("data-delay-vh")),
  delay_s = parseInt(consent.getAttribute("data-delay-s"))

// Youtube blocking feature
checkVideos = () => {
  preferences = window.cookieProPreferences
  document
    .querySelectorAll('[cookie-type="my-cookie[youtube]"]')
    .forEach(function (item) {
      if (
        preferences["my-cookie[youtube]"] === true ||
        typeof preferences !== "object"
      ) {
        item.setAttribute("cookie-state", "visible")
        item.setAttribute("src", item.getAttribute("data-src"))
      } else {
        item.setAttribute("cookie-state", "hidden")
        item.removeAttribute("src")

        if (!item.hasAttribute("data-has-placeholder")) {
          var placeholder = document.createElement("span")
          placeholder.innerHTML = item.getAttribute("cookie-placeholder")
          placeholder.classList.add("my-cookie__placeholder")
          insertAfter(item, placeholder)
          item.setAttribute("data-has-placeholder", "true")
        }
      }
    })
}

insertAfter = (referenceNode, newNode) => {
  referenceNode.parentNode.insertBefore(newNode, referenceNode.nextSibling)
}

savePreferences = (close = false) => {
  let preferences = {}
  let inputs = document.getElementsByClassName("my-cookie__toggle-checkbox")
  Array.prototype.forEach.call(inputs, input => {
    preferences[input.getAttribute("name")] = input.checked
  })
  localStorage.setItem("cookieProPrefences", JSON.stringify(preferences))
  window.cookieProPreferences = preferences
  if (close) closeSettings()
  hideConsent()
  checkVideos()
}

disableAll = (save = false) => {
  var inputs = document.getElementsByClassName("my-cookie__toggle-checkbox")
  Array.prototype.forEach.call(inputs, input => {
    input.checked = false
  })
  if (save) savePreferences(false)
}

enableAll = (save = false, close_consent = false) => {
  var inputs = document.getElementsByClassName("my-cookie__toggle-checkbox")
  Array.prototype.forEach.call(inputs, input => {
    input.checked = true
  })
  if (save) savePreferences(false)
  if (close_consent) toggleConsent()
}

closeSettings = () => {
  popup.classList.remove("active")
}

openSettings = () => {
  popup.classList.add("active")
  popup.classList.remove("declaration-open")
}

toggleConsent = () => {
  var consent = document.getElementById("my-cookie__consent")
  consent.classList.toggle("active")
}

hideConsent = () => {
  var consent = document.getElementById("my-cookie__consent")
  consent.classList.remove("active")
}

openDeclarationDirectly = () => {
  popup.classList.add("active")
  openDeclaration()
}

openDeclaration = () => {
  popup.classList.add("declaration-open")
}

closeDeclaration = () => {
  popup.classList.remove("declaration-open")
}

// Only for debugging
removeLocalStorage = () => {
  localStorage.removeItem("cookieProPrefences")
}

// If preferences not an object
if (typeof preferences !== "object") {
  // Show consent (we assume this is the first time user visits the website)
  if (delay == "1") {
    window.addEventListener("scroll", () => {
      let window_scroll = window.scrollY || document.documentElement.scrollTop // Fallback for IE
      if (
        window_scroll > delay_px &&
        typeof window.cookieProPreferences !== "object"
      )
        consent.classList.add("active")
    })
  } else if (delay == "2") {
    window.addEventListener("scroll", () => {
      let window_scroll = window.scrollY || document.documentElement.scrollTop //Fallback for IE
      if (
        window_scroll > document_height * delay_vh &&
        typeof window.cookieProPreferences !== "object"
      )
        consent.classList.add("active")
    })
  } else if (delay == "3") {
    setTimeout(function () {
      if (typeof window.cookieProPreferences !== "object")
        consent.classList.add("active")
    }, delay_s * 1000)
  } else {
    consent.classList.add("active")
  }
} else {
  // Organize checkboxes
  Object.keys(preferences).forEach(function (item) {
    if (
      document.querySelector(
        '.my-cookie__toggle-checkbox[name="' + item + '"]'
      ) !== null
    ) {
      const input = document.querySelector(
        '.my-cookie__toggle-checkbox[name="' + item + '"]'
      )
      input.checked = preferences[item]
    }
  })
}

// Look for all the plain text scripts
Array.prototype.forEach.call(scripts, item => {
  let script = item
  if (
    script.hasAttribute("cookie-type") &&
    script.getAttribute("type").toLowerCase() == "plain/text"
  ) {
    scriptsArray.push(script)
  }
})

// Append plain text scripts to the header
scriptsArray.forEach(function (item) {
  let script = item
  let name = item.getAttribute("cookie-type")
  // if preferences is not an object, we assume user enters website for the very first time
  // so all the tracking code is on
  if (preferences[name] === true || typeof preferences !== "object") {
    let el = document.createElement("script")

    if (script.hasAttribute("src")) {
      el.setAttribute("src", script.getAttribute("src"))
      el.setAttribute("async", "")
    } else {
      el.text = script.text
      el.setAttribute("type", "text/javascript")
    }
    document.getElementsByTagName("head")[0].appendChild(el)
  }
})

checkVideos()

// Click outside of the popup closes popup
window.addEventListener("click", function (e) {
  if (e.target.id !== "my-cookie__popup") return
  closeSettings()
})

// Key bindings
window.addEventListener("keyup", function (event) {
  if (event.key === "Escape") {
    if (popup.classList.contains("active")) closeSettings()
  }
})

//Event Listeners
document
  .getElementById("my-cookie__declaration-title")
  .addEventListener("click", () => {
    closeDeclaration()
  })

// Custom Triggers which can be used to open declaration/settings outside of the plugin
const custom_declaration_trigger = document.getElementsByClassName(
  "my-cookie__custom-declaration"
)
const custom_settings_trigger = document.getElementsByClassName(
  "my-cookie__custom-settings"
)

if (custom_declaration_trigger.length > 0) {
  Array.prototype.forEach.call(custom_declaration_trigger, trigger => {
    trigger.addEventListener("click", openDeclarationDirectly)
  })
}

if (custom_settings_trigger.length > 0) {
  Array.prototype.forEach.call(custom_settings_trigger, trigger => {
    trigger.addEventListener("click", openSettings)
  })
}

// Default Triggers

document
  .getElementById("my-cookie__cookie_declaration")
  .addEventListener("click", () => {
    openDeclaration()
  })
document
  .getElementById("my-cookie__cookie_settings")
  .addEventListener("click", () => {
    closeDeclaration()
  })
document
  .getElementById("my-cookie__turn_off_all")
  .addEventListener("click", () => {
    disableAll()
  })
document
  .getElementById("my-cookie__save_close")
  .addEventListener("click", () => {
    savePreferences(true)
  })
document
  .getElementById("click-toggleSettings")
  .addEventListener("click", () => {
    openSettings()
  })
document
  .getElementById("click-savePreferences")
  .addEventListener("click", () => {
    savePreferences(true)
  })
